"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactoForm = require("reacto-form");

var _lodash = require("lodash");

var _componentsContext = require("@reactioncommerce/components-context");

var _utils = require("../../utils");

/**
 * Convert the form document to the object structure
 * expected by `PaymentsCheckoutAction`
 * @param {Object} Form object
 * @returns {Object} Transformed object
 */
function buildResult(_ref) {
  var amount = _ref.amount,
      _ref$fullName = _ref.fullName,
      fullName = _ref$fullName === void 0 ? null : _ref$fullName;
  var floatAmount = amount ? parseFloat(amount) : null;
  if (isNaN(floatAmount)) floatAmount = null;
  return {
    amount: floatAmount,
    data: {
      fullName: fullName
    },
    displayName: fullName ? "IOU from ".concat(fullName) : null
  };
}
/**
 * @summary ExampleIOUPaymentForm component
 * @param {Object} props Props
 * @param {Object} ref Ref
 * @return {Object} React render
 */


function ExampleIOUPaymentForm(props, ref) {
  var lastDocRef = (0, _react.useRef)();
  var isReadyRef = (0, _react.useRef)();

  var _useState = (0, _react.useState)(),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      uniqueInstanceIdentifier = _useState2[0],
      setUniqueInstanceIdentifier = _useState2[1];

  if (!uniqueInstanceIdentifier) {
    setUniqueInstanceIdentifier((0, _lodash.uniqueId)("ExampleIOUPaymentForm"));
  }

  var className = props.className,
      _props$components = props.components,
      ErrorsBlock = _props$components.ErrorsBlock,
      Field = _props$components.Field,
      TextInput = _props$components.TextInput,
      isSaving = props.isSaving,
      _onChange = props.onChange,
      onReadyForSaveChange = props.onReadyForSaveChange,
      _onSubmit = props.onSubmit;

  var _useReactoForm = (0, _reactoForm.useReactoForm)({
    isReadOnly: isSaving,
    onChange: function onChange(formData) {
      var resultDoc = buildResult(formData);
      var stringDoc = JSON.stringify(resultDoc);

      if (stringDoc !== lastDocRef.current) {
        _onChange(resultDoc);
      }

      lastDocRef.current = stringDoc;
      var isReady = !!formData.fullName;

      if (isReady !== isReadyRef.current) {
        onReadyForSaveChange(isReady);
      }

      isReadyRef.current = isReady;
    },
    onSubmit: function onSubmit(formData) {
      return _onSubmit(buildResult(formData));
    }
  }),
      getErrors = _useReactoForm.getErrors,
      getInputProps = _useReactoForm.getInputProps,
      submitForm = _useReactoForm.submitForm;

  (0, _react.useImperativeHandle)(ref, function () {
    return {
      submit: function submit() {
        submitForm();
      }
    };
  });
  var fullNameInputId = "fullName_".concat(uniqueInstanceIdentifier);
  var amountInputId = "amount_".concat(uniqueInstanceIdentifier);
  return _react.default.createElement("div", {
    className: className
  }, _react.default.createElement(Field, {
    name: "fullName",
    errors: getErrors(["fullName"]),
    label: "Full name",
    labelFor: fullNameInputId
  }, _react.default.createElement(TextInput, (0, _extends2.default)({
    id: fullNameInputId
  }, getInputProps("fullName"))), _react.default.createElement(ErrorsBlock, {
    errors: getErrors(["fullName"])
  })), _react.default.createElement(Field, {
    name: "amount",
    errors: getErrors(["amount"]),
    label: "Amount (optional)",
    labelFor: amountInputId
  }, _react.default.createElement(TextInput, (0, _extends2.default)({
    id: amountInputId
  }, getInputProps("amount"))), _react.default.createElement(ErrorsBlock, {
    errors: getErrors(["amount"])
  })));
} // There is currently some issue with combining hoist-non-react-statics (used by
// withComponents) with forwardRef. Until that's resolved, reassigning
// ExampleIOUPaymentForm to the wrapped component here, before setting the statics.

/* eslint-disable-next-line no-func-assign */


ExampleIOUPaymentForm = (0, _componentsContext.withComponents)((0, _react.forwardRef)(ExampleIOUPaymentForm));
ExampleIOUPaymentForm.propTypes = {
  /**
   * You can provide a `className` prop that will be applied to the outermost DOM element
   * rendered by this component. We do not recommend using this for styling purposes, but
   * it can be useful as a selector in some situations.
   */
  className: _propTypes.default.string,

  /**
   * If you've set up a components context using
   * [@reactioncommerce/components-context](https://github.com/reactioncommerce/components-context)
   * (recommended), then this prop will come from there automatically. If you have not
   * set up a components context or you want to override one of the components in a
   * single spot, you can pass in the components prop directly.
   */
  components: _propTypes.default.shape({
    /**
     * Pass either the Reaction ErrorsBlock component or your own component that
     * accepts compatible props.
     */
    ErrorsBlock: _utils.CustomPropTypes.component.isRequired,

    /**
     * Pass either the Reaction Field component or your own component that
     * accepts compatible props.
     */
    Field: _utils.CustomPropTypes.component.isRequired,

    /**
     * Pass either the Reaction TextInput component or your own component that
     * accepts compatible props.
     */
    TextInput: _utils.CustomPropTypes.component.isRequired
  }),

  /**
   * Pass true while the input data is in the process of being saved.
   * While true, the form fields are disabled.
   */
  isSaving: _propTypes.default.bool,

  /**
   * Called as the form fields are changed
   */
  onChange: _propTypes.default.func,

  /**
   * When this action's input data switches between being
   * ready for saving and not ready for saving, this will
   * be called with `true` (ready) or `false`
   */
  onReadyForSaveChange: _propTypes.default.func,

  /**
   * Called with an object value when this component's `submit`
   * method is called. The object may have `data`, `displayName`,
   * and `amount` properties.
   */
  onSubmit: _propTypes.default.func
};
ExampleIOUPaymentForm.defaultProps = {
  isSaving: false,
  onChange: function onChange() {},
  onReadyForSaveChange: function onReadyForSaveChange() {},
  onSubmit: function onSubmit() {}
};
var _default = ExampleIOUPaymentForm;
exports.default = _default;